@@ -48,9 +48,10 @@ server <- function(input, output, session) {
   
   observe({
     billboarderProxy(shinyId = "mychart") %>% 
-      bb_transform(type = input$type)
+      bb_proxy_transform(type = input$type)
   })
   
+  shiny::onStop(shiny::stopApp)
 }
 
 shinyApp(ui = ui, server = server)
